users.My (My) — amici1

# `users.My` (My)

Actions

Mixin for tables on `Authored` which sets the requesting

  user as default value for the `author` filter parameter.

  If the table’s model does not inherit from `Authored`, then it must define a parameter field named “user” and a model attribute user. This feature is used by `lino_xl.lib.reception.models.MyWaitingVisitors`.

  Used by `lino_xl.lib.excerpts` and `lino_xl.lib.reception`.

## Filter parameters